/**********
 * Clip Constructor
 * create an object for each clip set
 */
function Clip(files, caption){
	this.caption = caption;
	this.videos = new Array();
	for(var i=0; i<files.length; i++) {
		this.videos[i] = new Video(files[i]);
	}
}
		
// Clip Method: returns if clip sets are complete
Clip.prototype.getComplete = function () {
	for(var i=0; i<this.videos.length; i++) {
		if(this.videos[i].url == "" && this.videos[i].type != "ad") {
			return false;
			break;
		}
	}
	return true;
};


/**********
 * Video Constructor
 * create an object for each video in a clip set
 */
function Video(file) {
	this.name = null;
	this.url = null;
	this.type = null;
	this.insite_start = null;
	this.insite_end = null;
	this.ad_start = null;
	this.ad_end = null;
	this.ad_button = null;
	this.ad_buttonclick = null;
	if(file != "ad") {
		this.name = file;
		this.url = this.getPathByName(file);
		this.type = "asset";
		this.setTracking();
	} else {
		this.setAd();
	}
}
		
// Video Method: sets properties for the ads
Video.prototype.setAd = function () {
	(null != document.frames["ad_data"].adClip) ? this.name = document.frames["ad_data"].adClip : this.name = adClip;
	this.url = this.getPathByName(this.name);
	this.type = "ad";
	this.setTracking();
};

// Video Method: sets tracking code for the videos & ads
Video.prototype.setTracking = function () {
	this.insite_start = "http://transfer.go.com/cgi/transfer.dll?srvc=sz&name=START_MOTION_WMV_" + this.name + "&goto=http://espn.go.com/i/blank.gif";
	this.insite_end = "http://transfer.go.com/cgi/transfer.dll?srvc=sz&name=END_MOTION_WMV_" + this.name + "&goto=http://espn.go.com/i/blank.gif";
	if(this.type == "ad") {
		null != document.frames["ad_data"].adTrack ? this.ad_start = document.frames["ad_data"].adTrack : this.ad_start = adTrack;
		this.ad_end = adTrackFinish;
		null != document.frames["ad_data"].adButton ? this.ad_button = document.frames["ad_data"].adButton : this.ad_button = adButton;
		null != document.frames["ad_data"].adButtonClick ? this.ad_buttonclick = document.frames["ad_data"].adButtonClick : this.ad_buttonclick = adButtonClick;
	}
};

// Video Method: get the local path of clips by name
Video.prototype.getPathByName = function (name) {
	var localPath = "";
	if(document.DIGStreamLocator != null && document.DIGStreamLocator.object != null) {
		localPath = DIGStreamLocator.GetLocalPathFromName("ESPNMotion", name);
	}
	return localPath;
};
		
		
/**********
 * Playlist Constructor
 * create an object for the playlist
 */
function Playlist(clips) {
	this.clips = clips;
	this.assets = new Array();
	this.viewed = this.getViewedCookie();
	this.current_asset = 0;
	this.current_video = 0;
	this.play_mode = null;
	var index = 0;
	for(var i=0; i<this.clips.length; i++) {
		if(this.clips[i].getComplete()) {
			this.assets[index] = this.clips[i];
			index ++;
		}
	}
}

// Playlist Method: determine if has assets
Playlist.prototype.getHasAssets = function () {
	return this.assets.length>0;
};

// Playlist Method: determine if automatically play motion
Playlist.prototype.getAutoPlay = function () {
	var play = -1;
	if (this.viewed != null && this.viewed.length > 0) {
		for (var i=0; i<this.assets.length; i++) {
			var temp = this.assets[i].caption;
			for (var j=0; j<this.viewed.length; j++) {
				if (temp == this.viewed[j].caption) {
					play = -1;
					break;
				} else {
					play = i; 
				}
			}
			if (play > -1) {
				break;
			}
		}
	} else {
		play = 0;
	}
	play > 0 ? this.play_mode = "archive" : null;
	return this.getHasAssets()
		&& play > -1
		&& autoStartVideo ? play : -1;
};

// Playlist Method: get/set property
Playlist.prototype.getAssetProperty = function (property) {
	return this.assets[this.current_asset].videos[this.current_video][property];
};

Playlist.prototype.setProperty = function (name, value) {
	this[name] = value;
};

// Playlist Method: play videos in each clip set
Playlist.prototype.playAssets = function () {
	if (this.current_video<this.assets[this.current_asset].videos.length) {
		if (this.getAssetProperty("url") != "") {
			document.frames[iframeID].Player.URL = this.getAssetProperty("url");
			this.trackAssets("start");
			readyToPlay();
			if (this.current_video == 0) {
				setTimeout("disablePlaylist()", 20000);
				this.appendViewedCookie(this.assets[this.current_asset].caption);
			}
		} else {
			++ this.current_video; 
			this.playAssets();
		}
	} else if (this.play_mode == "archive") {
		document.frames[iframeID].motionControls.TCallLabel("_level0", "next_clip");
		++ this.current_asset; 
		this.current_video = 0;
		if(this.current_asset<this.assets.length) {
			this.playAssets();
		} else {
			this.current_asset = 0;
			this.current_video = 0;
			document.frames[iframeID].Player.close();
			document.frames[iframeID].playerdiv.style.visibility = "hidden";
		}
	} else {
		this.current_asset = 0;
		this.current_video = 0;
		this.play_mode = "archive"
		changeiframe("topstory");
	}
};
		
// Playlist Method: track clips as they are started or completed
Playlist.prototype.trackAssets = function (tracktype) {
	document.frames[iframeID].motionbanner.style.visibility = "hidden";
	if (tracktype == "start") {
		document.frames[iframeID].trackVideoStart.src = this.getAssetProperty("insite_start");
		if (this.getAssetProperty("type") == "ad" ) {
			document.frames[iframeID].trackVideoAd.src = this.getAssetProperty("ad_start");
			document.frames[iframeID].motionbanner.style.visibility = "visible";
			document.frames[iframeID].adButton.src = this.getAssetProperty("ad_button");
			document.frames[iframeID].adButtonClick.href = this.getAssetProperty("ad_buttonclick");
			document.frames[iframeID].document.motionControls.TCallLabel("_level0", "enable");
			var rand = Math.floor(Math.random()*100);
			document.frames["ad_data"].location.replace(adFrameSrc + "&rand=" + rand);
		}
	} else if (tracktype == "end") {
		document.frames[iframeID].trackVideoEnd.src = this.getAssetProperty("insite_end");
		if (this.getAssetProperty("type") == "ad") {
			document.frames[iframeID].trackVideoAd.src = this.getAssetProperty("ad_end");
			this.setNewAd();
		}
	}
};

// Playlist Method: sets a new ad within the clip sets
Playlist.prototype.setNewAd = function () {
	for(var i=0; i<this.assets.length; i++) {
		for(var j=0; j<this.assets[i].videos.length; j++) {
			if(this.assets[i].videos[j].type == "ad") {
				this.assets[i].videos[j].setAd();
			}
		}
	}
};

// Return the active videos in the _viewed cookie
Playlist.prototype.getViewedCookie = function() {
	var clipsCookie = GetCookieUtil("espnmotion_viewed");
	var today = new Date();
	var time = today.getTime();
	var expire = time-(2 * 24 * 60 * 60 * 1000);

	if (clipsCookie != null) {
		var clipsArray = clipsCookie.split("|");
		for (var i=0; i<clipsArray.length; i++) {
			var properties = clipsArray[i].split("~");
			clipsArray[i] = {caption:properties[0], date:properties[1]};
		}
		for (var i=0; i<clipsArray.length; i++) {
			if (clipsArray[i].date < expire || clipsArray[i].caption == "") {
				clipsArray.splice(i,1);
				i--;
			}
		}
		return clipsArray;
	} else {
		return null;
	}
};

// Add active videos to the _viewed cookie
Playlist.prototype.appendViewedCookie = function(newclip) {
	var today = new Date();
	var time = today.getTime();
	var temp = newclip + "~" + time + "|";
	var append = {caption:newclip, date:time};
	if (this.viewed != null && this.viewed.length > 0) {
		var unseen = false;
		for (var i=0; i<this.viewed.length; i++) {
			if (newclip == this.viewed[i].caption) {
				unseen = false;
				break;
			} else {
				unseen = true; 
			}
		}
		if (unseen) {
			for (var i=0; i<this.viewed.length; i++) {
				temp += this.viewed[i].caption + "~" + this.viewed[i].date + "|";
			}
			SetCookieUtil("espnmotion_viewed",temp,oneWeek);
			this.viewed.push(append);
		}
	} else {
		SetCookieUtil("espnmotion_viewed",temp,oneWeek);
		this.viewed = new Array();
		this.viewed.push(append);
	}
};

function disablePlaylist() {
	if(null != document[iframeID].Player && document[iframeID].Player.playstate == 3) {
		document.frames[iframeID].document.motionControls.TCallLabel("_level0", "disable");
	}
}
		
// Insure Player Ready State
function readyToPlay() {
	if(null != document.getElementById('lowerad') && document[iframeID].Player.playstate == 10) {
		if(document.getElementById('lowerad').style.display == "none" || document.getElementById('lowerad').style.display == "block") {
			setTimeout("document[iframeID].Player.controls.play()", 100);
		} else {
			setTimeout("readyToPlay()", 50);	
		}
	} else if(document[iframeID].Player.playstate == 10) {
		setTimeout("document[iframeID].Player.controls.play()", 100);
	} else {
		setTimeout("readyToPlay()", 50);
	}
}